@@ -220,16 +220,16 @@ makeKeepaliveConnectString(char *target, int buflen, const ConnInfo *ci, BOOL ab
 #define OPENING_BRACKET '{'
 #define CLOSING_BRACKET '}'
 static const char *
-makeBracketConnectString(char **target, pgNAME item, const char *optname)
+makeBracketConnectString(BOOL in_str, char **target, pgNAME item, const char *optname)
 {
 	const char	*istr, *iptr;
 	char	*buf, *optr;
 	int	len;
 
-	istr = SAFE_NAME(item);
-	if (!istr[0])
+	if (!in_str)
 		return NULL_STRING;
 
+	istr = SAFE_NAME(item);
 	for (iptr = istr, len = 0; *iptr; iptr++)
 	{
 		if (CLOSING_BRACKET == *iptr)
@@ -292,6 +292,8 @@ makeConnectString(char *connect_string, const ConnInfo *ci, UWORD len)
 	BOOL		abbrev = (len < 1024) || 0 < ci->force_abbrev_connstr;
 	UInt4		flag;
 
+MYLOG(0, "%s row_versioning=%s\n", __FUNCTION__, ci->row_versioning);
+
 MYLOG(DETAIL_LOG_LEVEL, "force_abbrev=%d abbrev=%d\n", ci->force_abbrev_connstr, abbrev);
 	encode(ci->password, encoded_item, sizeof(encoded_item));
 	/* fundamental info */
@@ -352,6 +354,7 @@ MYLOG(DETAIL_LOG_LEVEL, "hlen=" FORMAT_SSIZE_T "\n", hlen);
 			INI_LOWERCASEIDENTIFIER "=%d;"
 			"%s"		/* INI_PQOPT */
 			"%s"		/* INIKEEPALIVE TIME/INTERVAL */
+			INI_NUMERIC_AS "=%d;"
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 			INI_XAOPT "=%d"	/* XAOPT */
 #endif /* _HANDLE_ENLIST_IN_DTC_ */
@@ -362,7 +365,7 @@ MYLOG(DETAIL_LOG_LEVEL, "hlen=" FORMAT_SSIZE_T "\n", hlen);
 			,ci->show_oid_column
 			,ci->row_versioning
 			,ci->show_system_tables
-			,makeBracketConnectString(&connsetStr, ci->conn_settings, INI_CONNSETTINGS)
+			,makeBracketConnectString(ci->conn_settings_in_str, &connsetStr, ci->conn_settings, INI_CONNSETTINGS)
 			,ci->drivers.fetch_max
 			,ci->drivers.unknown_sizes
 			,ci->drivers.max_varchar_size
@@ -382,8 +385,9 @@ MYLOG(DETAIL_LOG_LEVEL, "hlen=" FORMAT_SSIZE_T "\n", hlen);
 			,ci->bytea_as_longvarbinary
 			,ci->use_server_side_prepare
 			,ci->lower_case_identifier
-			,makeBracketConnectString(&pqoptStr, ci->pqopt, INI_PQOPT)
+			,makeBracketConnectString(ci->pqopt_in_str, &pqoptStr, ci->pqopt, INI_PQOPT)
 			,makeKeepaliveConnectString(keepaliveStr, sizeof(keepaliveStr), ci, FALSE)
+			,ci->numeric_as
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 			,ci->xa_opt
 #endif /* _HANDLE_ENLIST_IN_DTC_ */
@@ -459,18 +463,20 @@ MYLOG(DETAIL_LOG_LEVEL, "hlen=" FORMAT_SSIZE_T "\n", hlen);
 				ABBR_EXTRASYSTABLEPREFIXES "=%s;"
 				"%s"		/* ABBR_PQOPT */
 				"%s"		/* ABBRKEEPALIVE TIME/INTERVAL */
+				INI_NUMERIC_AS "=%d;"
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 				"%s"
 #endif /* _HANDLE_ENLIST_IN_DTC_ */
 				INI_ABBREVIATE "=%02x%x",
-				makeBracketConnectString(&connsetStr, ci->conn_settings, ABBR_CONNSETTINGS),
+				makeBracketConnectString(ci->conn_settings_in_str, &connsetStr, ci->conn_settings, ABBR_CONNSETTINGS),
 				ci->drivers.fetch_max,
 				ci->drivers.max_varchar_size,
 				ci->drivers.max_longvarchar_size,
 				ci->int8_as,
 				ci->drivers.extra_systable_prefixes,
-				makeBracketConnectString(&pqoptStr, ci->pqopt, ABBR_PQOPT),
+				makeBracketConnectString(ci->pqopt_in_str, &pqoptStr, ci->pqopt, ABBR_PQOPT),
 				makeKeepaliveConnectString(keepaliveStr, sizeof(keepaliveStr), ci, TRUE),
+				ci->numeric_as,
 #ifdef	_HANDLE_ENLIST_IN_DTC_
 				makeXaOptConnectString(xaOptStr, sizeof(xaOptStr), ci, TRUE),
 #endif /* _HANDLE_ENLIST_IN_DTC_ */
@@ -587,7 +593,7 @@ copyConnAttributes(ConnInfo *ci, const char *attribute, const char *value)
 		STRCPY_FIXED(ci->drivername, value);
 	else if (stricmp(attribute, INI_KDESC) == 0)
 		STRCPY_FIXED(ci->desc, value);
-	else if (stricmp(attribute, INI_DATABASE) == 0)
+	else if (stricmp(attribute, INI_DATABASE) == 0 || stricmp(attribute, ABBR_DATABASE) == 0)
 		STRCPY_FIXED(ci->database, value);
 	else if (stricmp(attribute, INI_SERVER) == 0 || stricmp(attribute, SPEC_SERVER) == 0)
 		STRCPY_FIXED(ci->server, value);
@@ -640,10 +646,12 @@ copyConnAttributes(ConnInfo *ci, const char *attribute, const char *value)
 	else if (stricmp(attribute, INI_CONNSETTINGS) == 0 || stricmp(attribute, ABBR_CONNSETTINGS) == 0)
 	{
 		/* We can use the conn_settings directly when they are enclosed with braces */
+		ci->conn_settings_in_str = TRUE;
 		ci->conn_settings = decode_or_remove_braces(value);
 	}
 	else if (stricmp(attribute, INI_PQOPT) == 0 || stricmp(attribute, ABBR_PQOPT) == 0)
 	{
+		ci->pqopt_in_str = TRUE;
 		ci->pqopt = decode_or_remove_braces(value);
 	}
 	else if (stricmp(attribute, INI_UPDATABLECURSORS) == 0 || stricmp(attribute, ABBR_UPDATABLECURSORS) == 0)
@@ -654,6 +662,8 @@ copyConnAttributes(ConnInfo *ci, const char *attribute, const char *value)
 		ci->true_is_minus1 = atoi(value);
 	else if (stricmp(attribute, INI_INT8AS) == 0)
 		ci->int8_as = atoi(value);
+	else if (stricmp(attribute, INI_NUMERIC_AS) == 0)
+		ci->numeric_as = atoi(value);
 	else if (stricmp(attribute, INI_BYTEAASLONGVARBINARY) == 0 || stricmp(attribute, ABBR_BYTEAASLONGVARBINARY) == 0)
 		ci->bytea_as_longvarbinary = atoi(value);
 	else if (stricmp(attribute, INI_USESERVERSIDEPREPARE) == 0 || stricmp(attribute, ABBR_USESERVERSIDEPREPARE) == 0)
@@ -786,6 +796,7 @@ getCiDefaults(ConnInfo *ci)
 	ci->lf_conversion = DEFAULT_LFCONVERSION;
 	ci->true_is_minus1 = DEFAULT_TRUEISMINUS1;
 	ci->int8_as = DEFAULT_INT8AS;
+	ci->numeric_as = DEFAULT_NUMERIC_AS;
 	ci->bytea_as_longvarbinary = DEFAULT_BYTEAASLONGVARBINARY;
 	ci->use_server_side_prepare = DEFAULT_USESERVERSIDEPREPARE;
 	ci->lower_case_identifier = DEFAULT_LOWERCASEIDENTIFIER;
@@ -1015,6 +1026,9 @@ MYLOG(0, "drivername=%s\n", drivername);
 	if (SQLGetPrivateProfileString(DSN, INI_INT8AS, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
 		ci->int8_as = atoi(temp);
 
+	if (SQLGetPrivateProfileString(DSN, INI_NUMERIC_AS, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
+		ci->numeric_as = atoi(temp);
+
 	if (SQLGetPrivateProfileString(DSN, INI_BYTEAASLONGVARBINARY, NULL_STRING, temp, sizeof(temp), ODBC_INI) > 0)
 		ci->bytea_as_longvarbinary = atoi(temp);
 
@@ -1272,6 +1286,11 @@ writeDSNinfo(const ConnInfo *ci)
 								 INI_INT8AS,
 								 temp,
 								 ODBC_INI);
+	ITOA_FIXED(temp, ci->numeric_as);
+	SQLWritePrivateProfileString(DSN,
+								 INI_NUMERIC_AS,
+								 temp,
+								 ODBC_INI);
 	SPRINTF_FIXED(temp, "%x", getExtraOptions(ci));
 	SQLWritePrivateProfileString(DSN,
 							INI_EXTRAOPTIONS,
@@ -1702,6 +1721,7 @@ CC_conninfo_init(ConnInfo *conninfo, UInt4 option)
 	conninfo->lf_conversion = -1;
 	conninfo->true_is_minus1 = -1;
 	conninfo->int8_as = -101;
+	conninfo->numeric_as = DEFAULT_NUMERIC_AS;
 	conninfo->bytea_as_longvarbinary = -1;
 	conninfo->use_server_side_prepare = -1;
 	conninfo->lower_case_identifier = -1;
@@ -1798,6 +1818,7 @@ CC_copy_conninfo(ConnInfo *ci, const ConnInfo *sci)
 	CORR_VALCPY(lf_conversion);
 	CORR_VALCPY(true_is_minus1);
 	CORR_VALCPY(int8_as);
+	CORR_VALCPY(numeric_as);
 	CORR_VALCPY(bytea_as_longvarbinary);
 	CORR_VALCPY(use_server_side_prepare);
 	CORR_VALCPY(lower_case_identifier);
