@@ -20,6 +20,7 @@
 #include <stdio.h>
 #include <string.h>
 
+
 #include "environ.h"
 #include "connection.h"
 #include "statement.h"
@@ -292,7 +293,7 @@ PGAPI_GetDiagField(SQLSMALLINT HandleType, SQLHANDLE Handle,
 							rc = QR_get_num_total_tuples(res) - res->dl_count;
 					}
 					*((SQLLEN *) DiagInfoPtr) = rc;
-MYLOG(1, "rc=" FORMAT_LEN "\n", rc);
+MYLOG(DETAIL_LOG_LEVEL, "rc=" FORMAT_LEN "\n", rc);
 					ret = SQL_SUCCESS;
 					break;
 				case SQL_DIAG_ROW_COUNT:
@@ -400,7 +401,7 @@ PGAPI_GetConnectAttr(HDBC ConnectionHandle,
 	RETCODE	ret = SQL_SUCCESS;
 	SQLINTEGER	len = 4;
 
-	MYLOG(0, "entering %d\n", Attribute);
+	MYLOG(0, "entering " FORMAT_INTEGER "\n", Attribute);
 	switch (Attribute)
 	{
 		case SQL_ATTR_ASYNC_ENABLE:
@@ -712,14 +713,14 @@ APDSetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 	}
 	if (RecNumber <=0)
 	{
-MYLOG(1, "RecN=%d allocated=%d\n", RecNumber, opts->allocated);
+MYLOG(DETAIL_LOG_LEVEL, "RecN=%d allocated=%d\n", RecNumber, opts->allocated);
 		DC_set_error(desc, DESC_BAD_PARAMETER_NUMBER_ERROR,
 				"bad parameter number");
 		return SQL_ERROR;
 	}
 	if (RecNumber > opts->allocated)
 	{
-MYLOG(1, "RecN=%d allocated=%d\n", RecNumber, opts->allocated);
+MYLOG(DETAIL_LOG_LEVEL, "RecN=%d allocated=%d\n", RecNumber, opts->allocated);
 		parameter_bindings_set(opts, RecNumber, TRUE);
 		/* DC_set_error(desc, DESC_BAD_PARAMETER_NUMBER_ERROR,
 				"bad parameter number");
@@ -881,7 +882,7 @@ IPDSetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 	}
 	if (RecNumber <= 0 || RecNumber > ipdopts->allocated)
 	{
-MYLOG(1, "RecN=%d allocated=%d\n", RecNumber, ipdopts->allocated);
+MYLOG(DETAIL_LOG_LEVEL, "RecN=%d allocated=%d\n", RecNumber, ipdopts->allocated);
 		DC_set_error(desc, DESC_BAD_PARAMETER_NUMBER_ERROR,
 				"bad parameter number");
 		return SQL_ERROR;
@@ -1160,7 +1161,7 @@ APDGetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 			break;
 		default:if (RecNumber <= 0 || RecNumber > opts->allocated)
 			{
-MYLOG(1, "RecN=%d allocated=%d\n", RecNumber, opts->allocated);
+MYLOG(DETAIL_LOG_LEVEL, "RecN=%d allocated=%d\n", RecNumber, opts->allocated);
 				DC_set_error(desc, DESC_BAD_PARAMETER_NUMBER_ERROR,
 					"bad parameter number");
 				return SQL_ERROR;
@@ -1414,7 +1415,7 @@ IPDGetField(DescriptorClass *desc, SQLSMALLINT RecNumber,
 			break;
 		default:if (RecNumber <= 0 || RecNumber > ipdopts->allocated)
 			{
-MYLOG(1, "RecN=%d allocated=%d\n", RecNumber, ipdopts->allocated);
+MYLOG(DETAIL_LOG_LEVEL, "RecN=%d allocated=%d\n", RecNumber, ipdopts->allocated);
 				DC_set_error(desc, DESC_BAD_PARAMETER_NUMBER_ERROR,
 					"bad parameter number");
 				return SQL_ERROR;
@@ -1551,7 +1552,7 @@ PGAPI_GetStmtAttr(HSTMT StatementHandle,
 	RETCODE		ret = SQL_SUCCESS;
 	SQLINTEGER	len = 0;
 
-	MYLOG(0, "entering Handle=%p %d\n", StatementHandle, Attribute);
+	MYLOG(0, "entering Handle=%p " FORMAT_INTEGER "\n", StatementHandle, Attribute);
 	switch (Attribute)
 	{
 		case SQL_ATTR_FETCH_BOOKMARK_PTR:	/* 16 */
@@ -1654,7 +1655,7 @@ PGAPI_SetConnectAttr(HDBC ConnectionHandle,
 	BOOL	unsupported = FALSE;
 	int	newValue;
 
-	MYLOG(0, "entering for %p: %d %p\n", ConnectionHandle, Attribute, Value);
+	MYLOG(0, "entering for %p: " FORMAT_INTEGER " %p\n", ConnectionHandle, Attribute, Value);
 	switch (Attribute)
 	{
 		case SQL_ATTR_METADATA_ID:
@@ -1811,7 +1812,7 @@ PGAPI_GetDescField(SQLHDESC DescriptorHandle,
 	RETCODE		ret = SQL_SUCCESS;
 	DescriptorClass *desc = (DescriptorClass *) DescriptorHandle;
 
-	MYLOG(0, "entering h=%p rec=%d field=%d blen=%d\n", DescriptorHandle, RecNumber, FieldIdentifier, BufferLength);
+	MYLOG(0, "entering h=%p rec=" FORMAT_SMALLI " field=" FORMAT_SMALLI " blen=" FORMAT_INTEGER "\n", DescriptorHandle, RecNumber, FieldIdentifier, BufferLength);
 	switch (DC_get_desc_type(desc))
 	{
 		case SQL_ATTR_APP_ROW_DESC:
@@ -1861,7 +1862,7 @@ PGAPI_SetDescField(SQLHDESC DescriptorHandle,
 	RETCODE		ret = SQL_SUCCESS;
 	DescriptorClass *desc = (DescriptorClass *) DescriptorHandle;
 
-	MYLOG(0, "entering h=%p(%d) rec=%d field=%d val=%p,%d\n", DescriptorHandle, DC_get_desc_type(desc), RecNumber, FieldIdentifier, Value, BufferLength);
+	MYLOG(0, "entering h=%p(%d) rec=" FORMAT_SMALLI " field=" FORMAT_SMALLI " val=%p," FORMAT_INTEGER "\n", DescriptorHandle, DC_get_desc_type(desc), RecNumber, FieldIdentifier, Value, BufferLength);
 	switch (DC_get_desc_type(desc))
 	{
 		case SQL_ATTR_APP_ROW_DESC:
@@ -1912,7 +1913,7 @@ PGAPI_SetStmtAttr(HSTMT StatementHandle,
 	CSTR func = "PGAPI_SetStmtAttr";
 	StatementClass *stmt = (StatementClass *) StatementHandle;
 
-	MYLOG(0, "entering Handle=%p %d," FORMAT_ULEN "(%p)\n", StatementHandle, Attribute, (SQLULEN) Value, Value);
+	MYLOG(0, "entering Handle=%p " FORMAT_INTEGER "," FORMAT_ULEN "(%p)\n", StatementHandle, Attribute, (SQLULEN) Value, Value);
 	switch (Attribute)
 	{
 		case SQL_ATTR_ENABLE_AUTO_IPD:	/* 15 */
@@ -1945,7 +1946,7 @@ PGAPI_SetStmtAttr(HSTMT StatementHandle,
 			else
 			{
 				stmt->ard = (DescriptorClass *) Value;
-MYLOG(1, "set ard=%p\n", stmt->ard);
+MYLOG(DETAIL_LOG_LEVEL, "set ard=%p\n", stmt->ard);
 			}
 			break;
 		case SQL_ATTR_APP_PARAM_DESC:	/* 10011 */
